@@ -1,5 +1,4 @@
 use std::os::unix::net::UnixStream;
-use std::sync::Mutex;
 
 #[test]
 #[ignore]
@@ -78,61 +77,62 @@ async fn start_dbus() {
     std::future::pending::<()>().await;
 }
 
-fn mock_loader() -> glycin_utils::Loader {
-    struct MockLoader {}
+struct MockLoader {}
 
-    impl glycin_utils::LoaderImplementation for MockLoader {
-        fn init(
-            &self,
-            _stream: UnixStream,
-            _mime_type: String,
-            _details: glycin_utils::InitializationDetails,
-        ) -> Result<glycin_utils::ImageInfo, glycin_utils::ProcessError> {
-            unimplemented!()
-        }
-        fn frame(
-            &self,
-            _frame_request: glycin_utils::FrameRequest,
-        ) -> Result<glycin_utils::Frame, glycin_utils::ProcessError> {
-            unimplemented!()
-        }
+impl glycin_utils::LoaderImplementation for MockLoader {
+    fn frame(
+        &mut self,
+        _frame_request: glycin_utils::FrameRequest,
+    ) -> Result<glycin_utils::Frame, glycin_utils::ProcessError> {
+        unimplemented!()
     }
 
-    let loader_impl = MockLoader {};
+    fn init(
+        _stream: UnixStream,
+        _mime_type: String,
+        _details: glycin_utils::InitializationDetails,
+    ) -> Result<(Self, glycin_utils::ImageDetails), glycin_utils::ProcessError> {
+        unimplemented!()
+    }
+}
 
+fn mock_loader() -> glycin_utils::Loader<MockLoader> {
     glycin_utils::Loader {
-        loader: Mutex::new(Box::new(loader_impl)),
+        loader: Default::default(),
+        image_id: Default::default(),
     }
 }
 
-fn mock_editor() -> glycin_utils::Editor {
-    struct MockEditor {}
+struct MockEditor {}
 
-    impl glycin_utils::EditorImplementation for MockEditor {
-        fn apply_sparse(
-            &self,
-            _stream: UnixStream,
-            _mime_type: String,
-            _details: glycin_utils::InitializationDetails,
-            _operations: glycin_utils::operations::Operations,
-        ) -> Result<glycin_utils::SparseEditorOutput, glycin_utils::ProcessError> {
-            unimplemented!()
-        }
-
-        fn apply_complete(
-            &self,
-            _stream: UnixStream,
-            _mime_type: String,
-            _details: glycin_utils::InitializationDetails,
-            _operations: glycin_utils::operations::Operations,
-        ) -> Result<glycin_utils::CompleteEditorOutput, glycin_utils::ProcessError> {
-            unimplemented!()
-        }
+impl glycin_utils::EditorImplementation for MockEditor {
+    fn edit(
+        _stream: UnixStream,
+        _mime_type: String,
+        _details: glycin_utils::InitializationDetails,
+    ) -> Result<Self, glycin_utils::ProcessError> {
+        unimplemented!()
     }
 
-    let editor_impl = MockEditor {};
+    fn create(
+        _mime_type: String,
+        _new_image: glycin_utils::NewImage,
+        _encoding_options: glycin_utils::EncodingOptions,
+    ) -> Result<glycin_utils::EncodedImage, glycin_utils::ProcessError> {
+        unimplemented!()
+    }
 
+    fn apply_complete(
+        &self,
+        _operations: glycin::Operations,
+    ) -> Result<glycin_utils::CompleteEditorOutput, glycin_utils::ProcessError> {
+        unimplemented!()
+    }
+}
+
+fn mock_editor() -> glycin_utils::Editor<MockEditor> {
     glycin_utils::Editor {
-        editor: Mutex::new(Box::new(editor_impl)),
+        editor: Default::default(),
+        image_id: Default::default(),
     }
 }
